@@ -15,9 +15,6 @@ from inspect import istraceback
 
 from collections import OrderedDict
 
-import requests
-import configparser
-import time
 
 # skip natural LogRecord attributes
 # http://docs.python.org/library/logging.html#logrecord-attributes
@@ -368,35 +365,6 @@ class JsonFormatter(logging.Formatter):
         # 3. add message field
         self.__add_field_in_log_from_record('addition_msg', event_entity, record)
 
-    def create_internal_request(self, log_record: Dict[str, Any]):
-
-        # 1. 读取配置文件
-        postapi_config = configparser.ConfigParser()
-        config_file = "config_5th.ini"
-        postapi_config.read(config_file)
-
-        api_status = postapi_config.get("global", "api_enable")
-
-        # 2. 创建post data
-        if api_status == "yes":
-            api_server_url =  postapi_config.get("global", "server_url_internal")
-            host_ip = postapi_config.get("global", "ip")
-            log_type = log_record['event_header'][-1]
-            timestamp = time.time()
-            localtime = time.localtime(timestamp)
-            default_time_format = '%Y-%m-%d %H:%M:%S'
-            log_time = time.strftime(default_time_format, localtime)
-            #log_time = log_record['event_header'][1]
-            str_message = json.dumps(log_record)
-
-            post_data = data = {"ip":host_ip,"type": "mimic_router","log_type": log_type,"time":log_time ,"message":str_message }
-            headers = {"Content-Type":"application/json"}
-            try:
-                response = requests.post(url=api_server_url,headers=headers,data=json.dumps(post_data),timeout=2.5)
-                response.raise_for_status()
-                return response.text
-            except requests.exceptions.RequestException as e:
-                return e
 
     def format(self, record: logging.LogRecord) -> str:
         """Formats a log record and serializes to json"""
