@@ -124,8 +124,9 @@ class JsonRotatingFileHandler(BaseRotatingHandler):
     def create_internal_request(self, log_record):
 
         # 1. 读取配置文件
+        #print (type(log_record))
         postapi_config = configparser.ConfigParser()
-        config_file = "config_5th.ini"
+        config_file = "/etc/mr/config_5th.ini"
         postapi_config.read(config_file)
 
         api_status = postapi_config.get("global", "api_enable")
@@ -162,7 +163,7 @@ class JsonRotatingFileHandler(BaseRotatingHandler):
             self.stream = self._open()
         if self.maxBytes > 0:                   # are we rolling over?
             msg = "%s\n" % self.format(record)
-            self.create_internal_request(msg)
+            self.create_internal_request(json.loads(msg))   #发送post报文给赛宁接口
             self.stream.seek(0, 2)  #due to non-posix-compliant Windows feature
             if self.stream.tell() + len(msg) >= self.maxBytes:
                 return 1
